==> pm2-monitor-0.0.1.tgz: package/pm2_monitor.js <==

var fs= require('fs'),
http = require('http'),
faye = require('faye'),
os = require('os'),
config = require('./config.js'),
auth = require("http-auth"),
shell = require('shelljs'),
crypto=require('crypto'),
ipm2 = require('pm2-interface')();
var hash;

if(process.argv.length > 2)
{

  var usuario = process.argv[2];
  var senha = process.argv[3];
  senha = senha === undefined ?"":senha;
  senha = createHash(senha);

  fs.writeFileSync("./pm2_authfile",usuario+":"+senha);
  config.auth.required = true;

}
if(!fs.existsSync(config.auth.file) && config.auth.required)
{

  process.kill();
  return;

}
else if(config.auth.required){

  var file = fs.readFileSync(config.auth.file).toString();
  hash = createHash(file);

  var basic = auth.basic({
    realm: "Monitoring Area"
  }, function (username, password, callback) {


    var usr = file.split(':')[0];
    var pwd = file.split(':')[1];

    callback(username === usr && pwd ===createHash(password));
    

  });

}
else
{

  hash = createHash(Math.random());

}


var bayeux = new faye.NodeAdapter({mount: '/'+hash, timeout: 45});


function callback(req,res)
{

  switch(req.url)
  {

    case "/scripts/main_scripts.js":
    {
      console.log('cheguei');
      res.writeHead(200, {"Content-Type": "text/javascript"});
      res.end(fs.readFileSync("./scripts/main_scripts.js"));

    }
    break;
    default:
    {
      var html = fs.readFileSync('./Index.html').toString();

      html =replace(html,'{0}',config.server.host);
      html =replace(html,'{1}',config.server.port);
      html = replace(html,'{2}',hash);

      res.writeHead(200, {"Content-Type": "text/html"});
      res.end(html);
    }
    break;
  }
}

if(config.auth.required)
{

  var bayeuxServer = http.createServer(basic,callback);
}
else{

  var bayeuxServer = http.createServer(callback);

}

bayeux.attach(bayeuxServer);

bayeuxServer.listen(config.server.port);

var client = new faye.Client('http://localhost:'+config.server.port+'/'+hash);



client.subscribe('/getdata', function(data) {

  switch(data.path)
  {
    case 'getdata':
    getAllProcesses();
    break;
    case 'stop':
    stopProcess(data.id);
    break;
    case 'start':
    startProcess(data.id);
    break;
    case 'restart':
    stopProcess(data.id);
    startProcess(data.id);
    break;
    case 'killall':
    killPm2();
    break;
    case"flush":
    shellCommand("pm2 flush");
    break;
    default:
    break;



  }

});

ipm2.on('ready', function() {

  ipm2.bus.on('*', function(event, data){

    getAllProcesses();
  });

  setInterval(getAllProcesses,3000);

});

function replace(_string,key,value)
{
  while(_string.indexOf(key) >=0)
  {


    _string = _string.replace(key,value);

  }

  return _string;

}
function createHash(_string) {


    // var string = JSON.stringify(_obj);
    var hash = crypto.createHash('md5').update(_string).digest('hex');

    return hash;

  }
  function startProcess(pm_id)
  {
    ipm2.rpc.startProcessId(pm_id, getAllProcesses);

  }
  function stopProcess(pm_id)
  {

    ipm2.rpc.stopProcessId(pm_id, getAllProcesses);


  }
  function restartProcess(pm_id)
  {

    ipm2.rpc.restartProcessId(pm_id, getAllProcesses);


  }
  function shellCommand(_command)
  {

   var result = shell.exec(_command).output;
 }


 function killPm2(){

  ipm2.rpc.killMe({}, getAllProcesses);


}


function getAllProcesses(){


  ipm2.rpc.getMonitorData({}, function(err, dt) {


    var rprocess = [];
    var startup=[];
    for (var item in dt)
    {

      var obj = {

        id : dt[item].pm_id,
        name:dt[item].name,
        restart:dt[item].pm2_env.restart_time,
        uptime:dt[item].pm2_env.pm_uptime,
        pid:dt[item].pid,
        memory:dt[item].monit.memory,
        cpu:dt[item].monit.cpu,
        status:dt[item].pm2_env.status,
        log:fs.readFileSync(dt[item].pm2_env.pm_out_log_path).length > (1024*1024) ? "Log muito grande , maior que 1 MB":fs.readFileSync(dt[item].pm2_env.pm_out_log_path).toString(),
        totalmem:os.totalmem()


      };

      startup.push({

        name:obj.name,
        script:dt[item].pm2_env.pm_exec_path,
        args:"",
        exec_mode:"fork_mode"


      });
      rprocess.push(obj);

    }
    if(config.startup && !fs.existsSync(config.startup.path))
    {
      fs.writeFileSync(config.startup.path, JSON.stringify(startup));
    }

    transmitData(rprocess);
  });


}

function transmitData(data){

  client.publish('/updates', {
    Data: data
  });


}

==> pm2-monitor-0.0.3.tgz: package/pm2_monitor.js <==

var fs= require('fs'),
http = require('http'),
faye = require('faye'),
os = require('os'),
config = require('./config.js'),
auth = require("http-auth"),
shell = require('shelljs'),
crypto=require('crypto'),
ipm2 = require('pm2-interface')();
var hash;

if(process.argv.length > 2)
{

  var usuario = process.argv[2];
  var senha = process.argv[3];
  senha = senha === undefined ?"":senha;
  senha = createHash(senha);

  fs.writeFileSync("./pm2_authfile",usuario+":"+senha);
  config.auth.required = true;

}
if(!fs.existsSync(config.auth.file) && config.auth.required)
{

  process.kill();
  return;

}
else if(config.auth.required){

  var file = fs.readFileSync(config.auth.file).toString();
  hash = createHash(file);

  var basic = auth.basic({
    realm: "Monitoring Area"
  }, function (username, password, callback) {


    var usr = file.split(':')[0];
    var pwd = file.split(':')[1];

    callback(username === usr && pwd ===createHash(password));
    

  });

}
else
{

  hash = createHash(Math.random());

}


var bayeux = new faye.NodeAdapter({mount: '/'+hash, timeout: 45});


function callback(req,res)
{

  switch(req.url)
  {

    case "/scripts/main_scripts.js":
    {
      
      res.writeHead(200, {"Content-Type": "text/javascript"});
      res.end(fs.readFileSync("./scripts/main_scripts.js"));

    }
    break;
    default:
    {
      var html = fs.readFileSync('./views/Index.html').toString();

      html =replace(html,'{0}',config.server.host);
      html =replace(html,'{1}',config.server.port);
      html = replace(html,'{2}',hash);

      res.writeHead(200, {"Content-Type": "text/html"});
      res.end(html);
    }
    break;
  }
}

if(config.auth.required)
{

  var bayeuxServer = http.createServer(basic,callback);
}
else{

  var bayeuxServer = http.createServer(callback);

}

bayeux.attach(bayeuxServer);

bayeuxServer.listen(config.server.port);

var client = new faye.Client('http://localhost:'+config.server.port+'/'+hash);



client.subscribe('/getdata', function(data) {

  switch(data.path)
  {
    case 'getdata':
    getAllProcesses();
    break;
    case 'stop':
    stopProcess(data.id);
    break;
    case 'start':
    startProcess(data.id);
    break;
    case 'restart':
    stopProcess(data.id);
    startProcess(data.id);
    break;
    case 'killall':
    killPm2();
    break;
    case"flush":
    shellCommand("pm2 flush");
    break;
    default:
    break;



  }

});

ipm2.on('ready', function() {

  ipm2.bus.on('*', function(event, data){

    getAllProcesses();
  });

  setInterval(getAllProcesses,3000);

});

function replace(_string,key,value)
{
  while(_string.indexOf(key) >=0)
  {


    _string = _string.replace(key,value);

  }

  return _string;

}
function createHash(_string) {


    // var string = JSON.stringify(_obj);
    var hash = crypto.createHash('md5').update(_string).digest('hex');

    return hash;

  }
  function startProcess(pm_id)
  {
    ipm2.rpc.startProcessId(pm_id, getAllProcesses);

  }
  function stopProcess(pm_id)
  {

    ipm2.rpc.stopProcessId(pm_id, getAllProcesses);


  }
  function restartProcess(pm_id)
  {

    ipm2.rpc.restartProcessId(pm_id, getAllProcesses);


  }
  function shellCommand(_command)
  {

   var result = shell.exec(_command).output;
 }


 function killPm2(){

  ipm2.rpc.killMe({}, getAllProcesses);


}


function getAllProcesses(){


  ipm2.rpc.getMonitorData({}, function(err, dt) {


    var rprocess = [];
    var startup=[];
    for (var item in dt)
    {

      var obj = {

        id : dt[item].pm_id,
        name:dt[item].name,
        restart:dt[item].pm2_env.restart_time,
        uptime:dt[item].pm2_env.pm_uptime,
        pid:dt[item].pid,
        memory:dt[item].monit.memory,
        cpu:dt[item].monit.cpu,
        status:dt[item].pm2_env.status,
        log:fs.readFileSync(dt[item].pm2_env.pm_out_log_path).length > (1024*1024) ? "Log muito grande , maior que 1 MB":fs.readFileSync(dt[item].pm2_env.pm_out_log_path).toString(),
        totalmem:os.totalmem()


      };

      startup.push({

        name:obj.name,
        script:dt[item].pm2_env.pm_exec_path,
        args:"",
        exec_mode:"fork_mode"


      });
      rprocess.push(obj);

    }
    if(config.startup && !fs.existsSync(config.startup.path))
    {
      fs.writeFileSync(config.startup.path, JSON.stringify(startup));
    }

    transmitData(rprocess);
  });


}

function transmitData(data){

  client.publish('/updates', {
    Data: data
  });


}
